summaryrefslogtreecommitdiffstats
path: root/chrome/test/pyautolib/pyautolib.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/test/pyautolib/pyautolib.h')
-rw-r--r--chrome/test/pyautolib/pyautolib.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chrome/test/pyautolib/pyautolib.h b/chrome/test/pyautolib/pyautolib.h
index 3abe987..a3a8e23 100644
--- a/chrome/test/pyautolib/pyautolib.h
+++ b/chrome/test/pyautolib/pyautolib.h
@@ -135,23 +135,23 @@ class PyUITestBase : public UITestBase {
std::string _GetBookmarksAsJSON();
// Editing of the bookmark model. Bookmarks are referenced by id.
// The id is a string16, not an int64, for convenience, since
// the python side gets IDs converted from a JSON representation
// (which "extracts" into a string, not an int). Since IDs are
// grabbed from the current model (and not generated), a conversion
// is unnecessary. URLs are strings and not GURLs for a similar reason.
// Bookmark or group (folder) creation:
- bool AddBookmarkGroup(const string16& parent_id, int index,
- const string16& title);
- bool AddBookmarkURL(const string16& parent_id, int index,
- const string16& title, const string16& url);
+ bool AddBookmarkGroup(std::wstring& parent_id, int index,
+ std::wstring& title);
+ bool AddBookmarkURL(std::wstring& parent_id, int index,
+ std::wstring& title, std::wstring& url);
// Bookmark editing:
- bool ReparentBookmark(const string16& id, const string16& new_parent_id,
+ bool ReparentBookmark(std::wstring& id, std::wstring& new_parent_id,
int index);
- bool SetBookmarkTitle(const string16& id, const string16& title);
- bool SetBookmarkURL(const string16& id, const string16& url);
+ bool SetBookmarkTitle(std::wstring& id, std::wstring& title);
+ bool SetBookmarkURL(std::wstring& id, std::wstring& url);
// Finally, bookmark deletion:
- bool RemoveBookmark(const string16& id);
+ bool RemoveBookmark(std::wstring& id);
// Get a handle to browser window at the given index, or NULL on failure.
scoped_refptr<BrowserProxy> GetBrowserWindow(int window_index);
@@ -135,23 +135,23 @@ class PyUITestBase : public UITestBase {
std::string _GetBookmarksAsJSON();
// Editing of the bookmark model. Bookmarks are referenced by id.
- // The id is a string16, not an int64, for convenience, since
+ // The id is a std::wstring, not an int64, for convenience, since
// the python side gets IDs converted from a JSON representation
// (which "extracts" into a string, not an int). Since IDs are